# TODO

- Evaluate whether documenting raised exceptions in docstrings is worth it
- Remove superfluous comments again
- Maybe have a look over complexity-related rules I ignore in noqa comments
- in the docs, could inline code examples have syntax highlighting
- When I show the errors from tests, the message of the AssertionFailure is shown twice.
